#
# spec file for package kdevelop5
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# for compatibility with Leap 42.3 which doesn't have this macro yet
%{!?_kf5_debugdir: %global _kf5_debugdir %{_kf5_configdir}}
%define rname   kdevelop
%define rversion 5.3
%define libkdev_major 53
Name:           kdevelop5
Version:        5.3.2
Release:        lp151.2.3.1
Summary:        Plugin-extensible IDE for C/C++ and other programming languages
License:        GPL-2.0-or-later
Group:          Development/Tools/IDE
URL:            https://www.kdevelop.org
Source0:        https://download.kde.org/stable/%{rname}/%{version}/src/%{rname}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM
Patch:          Fix-version-check-for-GDB-10.x.patch
BuildRequires:  grantlee5-devel
BuildRequires:  karchive-devel
BuildRequires:  kcmutils-devel
BuildRequires:  kconfig-devel
BuildRequires:  kcrash-devel
BuildRequires:  kdeclarative-devel
BuildRequires:  kdevelop5-pg-qt
BuildRequires:  kdoctools-devel
BuildRequires:  kf5-filesystem
BuildRequires:  kguiaddons-devel
BuildRequires:  ki18n-devel
BuildRequires:  kiconthemes-devel
BuildRequires:  kio-devel
BuildRequires:  kitemmodels-devel
BuildRequires:  kitemviews-devel
BuildRequires:  kjobwidgets-devel
BuildRequires:  knewstuff-devel
BuildRequires:  knotifications-devel
BuildRequires:  knotifyconfig-devel
BuildRequires:  kparts-devel
BuildRequires:  krunner-devel
BuildRequires:  kservice-devel
BuildRequires:  ktexteditor-devel
BuildRequires:  kwindowsystem-devel
BuildRequires:  kxmlgui-devel
BuildRequires:  libkomparediff2-devel
BuildRequires:  libksysguard5-devel
BuildRequires:  llvm-clang-devel
BuildRequires:  okteta-devel
BuildRequires:  pkgconfig
BuildRequires:  plasma-framework-devel
BuildRequires:  purpose-devel
BuildRequires:  shared-mime-info
BuildRequires:  subversion-devel
BuildRequires:  threadweaver-devel
BuildRequires:  cmake(Qt5Concurrent)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Help)
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  cmake(Qt5QuickWidgets)
BuildRequires:  cmake(Qt5Script)
BuildRequires:  cmake(Qt5Test)
%ifarch %{ix86} x86_64 %{arm} aarch64 mips mips64
BuildRequires:  cmake(Qt5WebEngineWidgets)
%else
BuildRequires:  cmake(Qt5WebKitWidgets)
%endif
BuildRequires:  cmake(Qt5Widgets)
# contains the headers that are needed for the C++ parser to work (see boo#1119186)
%if 0%{?suse_version} > 1320
Requires:       clang%(rpm -q --qf '%''{version}' clang-devel | cut -d. -f1)
%else
Requires:       clang
%endif
Recommends:     %{name}-lang
Recommends:     clazy
Recommends:     cppcheck
Recommends:     heaptrack-gui
Conflicts:      kdevelop4
Conflicts:      kdevelop4-plugin-clang
# To allow "zypper in kdevelop"
Provides:       kdevelop = %{version}
# The following plugins were provided by the KDE repos providing unstable packages
Provides:       kdevelop5-cpp-parser
Provides:       kdevelop5-plugin-qmljs = %{version}
Obsoletes:      kdevelop5-plugin-qmljs < %{version}
Provides:       kdevelop5-plugin-clang = %{version}
Obsoletes:      kdevelop5-plugin-clang < %{version}
Provides:       kdevelop5-plugin-qmake = %{version}
Obsoletes:      kdevelop5-plugin-qmake < %{version}
Provides:       kdevelop5-plugin-cppsupport = %{version}
Obsoletes:      kdevelop5-plugin-cppsupport < %{version}
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
# It does not build with the default compiler (GCC 4.8) on Leap 42.x
BuildRequires:  gcc7-c++
%endif

%description
KDevelop is an integrated development environment (IDE).
It provides editing, navigation and debugging features for several programming languages,
as well as integration with multiple build systems and version-control systems
using a plugin-based architecture.
KDevelop has parser backends for C, C++ and Javascript/QML,
with further external plugins supporting e.g. PHP or Python.

%package -n kdevplatform
Summary:        Base Package for Integrated Development Environments
Group:          Development/Tools/IDE
Requires:       libkdevplatform%{libkdev_major} = %{version}
Recommends:     kdevplatform-lang
Conflicts:      kdevplatform4
Conflicts:      libkdevplatform4-devel

%description -n kdevplatform
This package contains the common plugins for integrated developments
environment based on the KDevelop framework.

%package -n libkdevplatform%{libkdev_major}
Summary:        Libraries for Integrated Development Environments
Group:          Development/Tools/IDE
Requires:       kdevplatform
Obsoletes:      libkdevplatform10 < %{version}

%description -n libkdevplatform%{libkdev_major}
This package contains the libraries for integrated development
environments based on the KDevelop framework.

%package -n kdevplatform-devel
Summary:        Base Package for Integrated Development Environments: Build Environment
Group:          Development/Tools/IDE
Requires:       libkdevplatform%{libkdev_major} = %{version}
Conflicts:      libkdevplatform4-devel
# Not installed automatically
Requires:       ktexteditor-devel
Requires:       threadweaver-devel

%description -n kdevplatform-devel
This package contains the development files for building integrated
developments environments based on the KDevelop framework.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Supplements:    packageand(bundle-lang-other:%{name})
Conflicts:      kdevelop4-lang
Provides:       %{name}-lang-all = %{version}
BuildArch:      noarch

%description lang
Provides translations to the package %{name}

%package -n kdevplatform-lang
Summary:        Translations for package kdevplatform
Group:          System/Localization
Requires:       kdevplatform = %{version}
Supplements:    packageand(bundle-lang-other:kdevplatform)
Conflicts:      kdevplatform4-lang
Provides:       kdevplatform-lang-all = %{version}
BuildArch:      noarch

%description -n kdevplatform-lang
Provides translations to the package kdevplatform

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%if 0%{?suse_version} <= 1325
  # It does not build with the default compiler (GCC 4.8) on Leap 42.x
  export CC=gcc-7
  export CXX=g++-7
%endif
  %cmake_kf5 -d build
  %make_jobs

%install
  %kf5_makeinstall -C build

  names="kdevandroid kdevappwizard kdevastyle kdevbazaar kdevclang kdevclassbrowser \
         kdevclazy kdevcmake kdevcmakebuilder kdevcodeutils kdevcontextbrowser \
         kdevcppcheck kdevcustombuildsystem kdevcustomdefinesandincludes kdevcustommake \
         kdevcustomscript kdevdebuggercommon kdevdocker kdevdocumentswitcher \
         kdevdocumentview kdevelop kdevexecute kdevexecuteplasmoid kdevexecutescript \
         kdevexternalscript kdevfilemanager kdevfiletemplates kdevflatpak kdevgdb \
         kdevghprovider kdevgit kdevgrepview kdevheaptrack kdevkdeprovider kdevkonsole kdevlldb \
         kdevmakebuilder kdevmanpage kdevninja kdevokteta kdevopenwith kdevpatchreview \
         kdevperforce kdevproblemreporter kdevprojectfilter kdevprojectmanagerview \
         kdevqmakebuilder kdevqmakemanager kdevqmljs kdevqthelp kdevquickopen \
         kdevsourceformatter kdevoutlineview kdevstandardoutputview kdevsubversion  \
         kdevswitchtobuddy kdevtestview kdevvcsprojectintegration kdevwelcomepage \
         plasma_applet_kdevelopsessions plasma_runner_kdevelopsessions"

  for name in $names; do
    %find_lang $name %{name}.lang
  done

  %find_lang kdevplatform kdevplatform.lang

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%post -n kdevplatform -p /sbin/ldconfig
%postun -n kdevplatform -p /sbin/ldconfig
%post -n libkdevplatform%{libkdev_major} -p /sbin/ldconfig
%postun -n libkdevplatform%{libkdev_major} -p /sbin/ldconfig

%files -n libkdevplatform%{libkdev_major}
%license kdevplatform/COPYING*
%{_kf5_libdir}/libKDevPlatform*.so.*

%files
%license COPYING*
%doc README.md
%dir %{_kf5_iconsdir}/hicolor/256x256
%dir %{_kf5_iconsdir}/hicolor/256x256/apps
%dir %{_kf5_iconsdir}/hicolor/512x512
%dir %{_kf5_iconsdir}/hicolor/512x512/apps
%dir %{_kf5_iconsdir}/hicolor/1024x1024
%dir %{_kf5_iconsdir}/hicolor/1024x1024/apps
%doc %lang(en) %{_kf5_htmldir}/en/kdevelop
%exclude %{_kf5_iconsdir}/hicolor/*/actions/breakpoint.*
%{_kf5_applicationsdir}/*kdevelop*.desktop
%{_kf5_appstreamdir}/org.kde.kdevelop.appdata.xml
%{_kf5_bindir}/kdev_includepathsconverter
%{_kf5_bindir}/kdevelop*
%{_kf5_debugdir}/kdevelop.categories
%{_kf5_iconsdir}/*/*/*/*
%{_kf5_libdir}/cmake/KDevelop/
%{_kf5_libdir}/libKDevClangPrivate.so.*
%{_kf5_libdir}/libkdevcmakecommon.so
%{_kf5_notifydir}/kdevelop.notifyrc
%{_kf5_plasmadir}/
%{_kf5_plugindir}/kdevplatform/
%{_kf5_plugindir}/krunner_kdevelopsessions.so
%{_kf5_plugindir}/plasma/
%{_kf5_prefix}/include/kdevelop/
%{_kf5_qmldir}/
%{_kf5_servicesdir}/kdevelopsessions.desktop
%{_kf5_servicesdir}/plasma-applet-kdevelopsessions.desktop
%{_kf5_servicesdir}/plasma-dataengine-kdevelopsessions.desktop
%{_kf5_sharedir}/kdevappwizard/
%{_kf5_sharedir}/kdevclangsupport/
%{_kf5_sharedir}/kdevcodegen/
%{_kf5_sharedir}/kdevcodeutils/
%{_kf5_sharedir}/kdevelop/
%{_kf5_sharedir}/kdevfiletemplates/
%{_kf5_sharedir}/kdevgdb/
%{_kf5_sharedir}/kdevlldb/
%{_kf5_sharedir}/kdevmanpage/
%{_kf5_sharedir}/kdevqmljssupport/
%{_kf5_sharedir}/mime/packages/kdevclang.xml
%{_kf5_sharedir}/mime/packages/kdevelop.xml
%{_kf5_sharedir}/mime/packages/kdevgit.xml

%files lang -f %{name}.lang

%files -n kdevplatform-lang -f kdevplatform.lang

%files -n kdevplatform
%license kdevplatform/COPYING*
%doc kdevplatform/README.md
%{_kf5_bindir}/kdev_dbus_socket_transformer
%{_kf5_bindir}/kdev_format_source
%{_kf5_bindir}/kdevplatform_shell_environment.sh
%{_kf5_debugdir}/kdevplatform.categories
%{_kf5_iconsdir}/hicolor/*/actions/breakpoint.*
%{_kf5_plugindir}/grantlee/
%{_kf5_servicetypesdir}/
%{_kf5_sharedir}/kdevplatform/

%files -n kdevplatform-devel
%license kdevplatform/COPYING*
%{_kf5_libdir}/libKDevPlatform*.so
%{_kf5_libdir}/cmake/KDevPlatform/
%{_kf5_prefix}/include/kdevplatform/

%changelog
* Sat Jan  9 2021 wbauer@tmo.at
- Add Fix-version-check-for-GDB-10.x.patch to make debugging work
  with gdb-10.x (kde#428688)
* Thu Mar  7 2019 wbauer@tmo.at
- New upstream release 5.3.2
  * Don't call clear() on a shared pointer we don't own
    (kde#403644)
  * Workaround the bug found by ASan, which can be seen on FreeBSD
    CI
  * Kdev-clazy: use canonical paths
  * Prevent the Extra Arguments ComboBox to Stretch Too Much
  * CMake plugin: don't hardcode a default install prefix
  * Appimage: skip unneeded cp of cmake, removed later again
  * Clang plugin: Handle CUDA files better
  * Clang: detect Clang builtin dirs at runtime on Unix
  * Actually cleanup the duchain from the background thread
    (kde#388743)
  * Appimage: add okteta libs, as used by the debugger memory view
  * Grepview: Fix potential crash in "Find in Files" (kde#402617)
  * Add All Top-Level Targets to the Menu
  * Show "Move into Source" action in code menu
  * QuickOpen: Trim whitespace from input
  * Update kdevelop app icon to latest breeze-icons version
  * Appimage: have only kdevelop appdata in the appimage
  * Fix first run of appimage creation: get install_colorschemes.py
    via $SRC
  * Fix crash in documentation view (kde#402026)
  * CMake: skip server entries without empty build system
    information
  * 2 missing KTextEditorPluginIntegration::MainWindow slots
  * Polish Purpose integration in the PatchReview plugin
  * Hex editor plugin: prepare for incompatible API change of
    libraries from upcoming Okteta 0.26.0
- Require clangX instead of clang on Leap 15 and TW, the exact
  version should not matter anymore
* Sat Dec 22 2018 wbauer@tmo.at
- New upstream release 5.3.1
  * Remove the CVS plugin. This was unusable and would crash if
    used in most cases, but accidentally remained in 5.3.0
  * Don't add 'override' specifier for non-modern project settings
    (kde#372280)
  * Use qCWarning in path.cpp
  * Fix qmakeproject unittest to work on Windows
  * Fix defines and includes test to run on Windows
  * Fix projectmodel unittest to work on Windows
  * Make the filteringstrategy test work on Windows as well
  * Fix problem model test on Windows. Make sure that when we
    create a path the root of that path is created according to
    what is expected on the current platform. E.g. C: on Windows.
  * Appimage: use original app desktop file as base for appimage
    one
  * Make test outputmodel pass on windows.
  * Increase timeout for duchain gcc compatibility test
  * Auto-find Clazy documentation also with clazy >= 1.4
    (kde#401075)
  * Disable plugin project config if project without a
    IBuildSystemManager dep (kde#400769)
  * Appimage: Do not bundle libfontconfig
  * Cmake: fix missing addition of policies to documentation index
  * FunctionDefinition: only look for (new/other) function
    definition if we don't have one
  * Fix memleaks in duchain unittests
- Drop Auto-find-Clazy-documentation-also-with-clazy-1.4.patch,
  merged upstream
- Use cmake() notation for the Qt BuildRequires instead of
  pkgconfig()
* Sun Dec 16 2018 wbauer@tmo.at
- Require clang, without it the C++ parser won't work (boo#1119186)
* Sat Dec  1 2018 Fabian Vogt <fabian@ritter-vogt.de>
- Add kdevelop provides
* Fri Nov 16 2018 wbauer@tmo.at
- Add Auto-find-Clazy-documentation-also-with-clazy-1.4.patch to
  make the clazy plugin find the necessary documentation also with
  clazy 1.4+, which installs it to a different place than previous
  versions (kde#401075)
* Wed Nov 14 2018 wbauer@tmo.at
- New upstream release 5.3.0
  * New clazy analyzer plugin
  * Clang: include tooltips: fix range check
  * Allow overriding the path to the builtin clang compiler headers
    (kde#393779)
  * Always use the clang builtin headers for the libclang version
    we use (kde#387005)
  * Group completion requests and only handle the last one
  * Fix Template (Class/Function) Signatures in Clang Code
    Completion (kde#368544, kde#377397)
  * Workaround: find declarations for constructor argument hints
  * Clang: Improve argument hint code completion
- Drop kdevplatform-reduce-dependencies.diff, merged upstream
- Recommend clazy which is needed by the new clazy plugin
- Remove explicitly versioned kdevplatform requirement,
  libkdevplatformXY is implicitly required anyway, that should be
  sufficient
- Use QtWebKit on platforms where QtWebEngine is not available
- Use gcc7 for building on Leap 42.3, compilation fails with the
  default 4.8
* Tue Oct 16 2018 Fabian Vogt <fabian@ritter-vogt.de>
- Use WebEngine instead of WebKit
* Fri Aug 31 2018 Christophe Giboudeaux <christophe@krop.fr>
- Add requirements for kdevplatform-devel which are not detected
  automatically.
* Fri Aug 31 2018 Christophe Giboudeaux <christophe@krop.fr>
- Add kdevplatform-reduce-dependencies.diff to prevent adding
  unneeded requirements to the kdevplatform-devel package.
* Wed Aug 29 2018 Christophe Giboudeaux <christophe@krop.fr>
- Run spec-cleaner
* Tue Aug 21 2018 wbauer@tmo.at
- New upstream release 5.2.4
  * Fix resizing of variable tooltip
  * Fix various problems with filters in the output view
    (kde#343124)
  * Fix a crash which could happen when using the class browser in
    debug builds with Qt >= 5.11
  * Only show cppcheck menu for cpp files
- Move all plugins from kdevplatform to the main package following
  upstream more closely, the kdevplatform package now only contains
  files coming from the "kdevplatform" directory in the source
  (kdevelop5 is the only application using kdevplatform anyway)
* Fri May 25 2018 wbauer@tmo.at
- New upstream release 5.2.3 (5.2.2 has been skipped)
  * KDevelop : support whitespace between the '#' and 'include' (or
    'import') (kde#394200)
  * Shell: Display generic project managers again
  * Github: Fix Github repositories not fetched (kde#392553)
  * Avoid emptry entries in project files filter list
  * Note org.kdevelop.IBasicVersionControl@kdevgit as dep for
    kdevghprovider
  * Never assert when the assert can fire sporadically (kde#357585)
  * Sublime: Release space in tab bar when no status (kde#314167)
  * Shell: Save entries of recent projects action (kde#385915)
  * Lldb: don't issue command when there's no env variables to set
    (kde#391897)
  * Fix crash when activating code completion item (kde#391742)
  * Do not add return type to constructors declaration when editing
    definition in signature assistant (kde#365420)
  * Make lambda introduce a context in DU chain (kde#387994)
  * Fix bug 384082 - cppcheck is checking CMake generated files
    (kde#384082)
  * Never run qmlplugindump on plugins that already offer
    plugins.qmltypes
  * Fix CodeCompletion of Strongly Typed Enum
  * Make sure qmlplugindump works on my system
  * Make sure we don't crash when stopping all jobs
  * Help automoc to find metadata JSON files referenced in the
    code
  * Link against KF5::Purpose if it's available
  * Properly quote expected string value in lldb formatter
    unittests
  * Unbreak the GDB QUrl pretty printer test
  * Unbreak QtPrintersTest::testQString
  * Also unbreak QtPrintersTest::testQByteArray
  * Work around bug in kLineEdit (kde#373004)
  * Fix crash when stopping process
  * Performance: Reuse the global icon loader
  * Cache ProblemPointers per translation unit (kde#386720)
  * Only set CMAKE_AUTOMOC_MACRO_NAMES with KF5 < 5.42
  * Format comments before setting them on the DUChain
  * Set toolbar/toolbutton font on quickopen line edit
- New upstream release 5.2.1
  * Fix a crash which often happened when switching git branches in
    the background in C++ projects. This temporarily disables
    documentation warnings, as well as parsed documentation display
    in the tooltips, until the underlying issue is fixed upstream.
    (kde#358205)
  * Fix a crash happening on some systems when opening a session
    (kde#384162)
  * Fix include path completion not showing project-defined system
    includes (i.e. includes added as system includes but by your
    project) (kde#386421)
  * Fix crash when batch-editing defines in the define editor
    (kde#386709)
  * Fix an assert (only happened in debug mode) and potential crash
    when showing problem tooltip (kde#386901)
  * Fix targets being duplicated when using CMake subprojects
    (kde#387095)
  * Fix console toolview asking to delete a temporary file
    interactively (kde#379652)
  * Fix a lot of AUTOMOC warnings while compiling with CMake 3.10
  * Fix some tool view context menus having empty entries
    (kde#386911)
  * Fix the progress widget in the statusbar not showing in some
    sessions
  * Adapt cache clear logic to ensure that the code model cache
    (~/.cache/kdevduchain) is always cleared when changing to a
    different KDevelop version (including patch versions).
    Unsuitable data in the cache has caused a range of issues in
    the past, including crashes. If you really need to keep the
    cache, you can create an (empty) file with the version suffix
    of the target version in the cache folder.
  * Fix KDevelop not starting up with the welcome page enabled
    (which it is by default) on systems without OpenGL support
    (kde#386527)
  * Fix build with Qt version 5.5
- New upstream release 5.2.0
  * For a list of changes, see:
    https://www.kdevelop.org/news/kdevelop-520-released
  * New analyzers: heaptrack, cppcheck
  * Improved C++ support, notable fixes include:
    + Properly pass on some categories of compiler flags from the
    build system to the analyzer, fixing e. g. parse errors in
    some Qt header files which cannot be parsed if a certain
    compiler configuration is not respected
    + Improve performance of C++ code completion in some situations
    + Restore some completion features from 4.x, such as automatic
    insertion of semicolons in some cases
- Add (lib)kdevplatform subpackages that were provided by
  kdevplatform previously which is merged into kdevelop itself now
- Recommend cppcheck and heaptrack-gui to make the new analyzer
  plugins work out of the box
- Adjust build requirements and filelists
- Mark license files with %%license instead of %%doc
- Make libkdevplatform52 obsolete libkdevplatform10 to prevent
  update problems, and don't require the exact same version of
  kdevplatform to avoid such problems in the future when the so
  version is bumped again
* Tue Aug 29 2017 wbauer@tmo.at
- New upstream release 5.1.2
  * Fixed a crash in the cmake lexer (kde#363269)
  * Various small improvements in cmake and C++ code completion
  * Fix placement of C++ #include completions
  * Fix a crash with JS projects on remote directories (kde#369573)
  * Source formatting preview is back
* Wed Jun  7 2017 jengelh@inai.de
- Remove empty phrasing from description.
* Sat May 27 2017 wbauer@tmo.at
- New upstream release 5.1.1
  * Install xdg mimetype definition for OpenCL C
  * Move print from int to unsigned int
  * Fix build for MinGW (kde#379454)
  * Look for Cppcheck as RUNTIME dependencies
  * The OpenCL language is actually called OpenCL C
  * Remove unneeded mimetype for *.kdevinternal files
  * Create KAboutData object only after QApp instance, for working
    translations
  * CMake - fix bug with dropping changed settings for existing
    build directory
  * Drop explicit %%{PROJECTDIR}/ from templates'
    ShowFilesAfterGeneration
  * Remove unused "VersionControl" entries from kdev4
    samples/templates
  * Fix ShowFilesAfterGeneration to match generated files
    (kde#378499)
  * Update Qt logo image
- Changed package summary/description as requested in boo#1034320
* Thu Mar 23 2017 wbauer@tmo.at
- New upstream release 5.1.0
  * For a list of changes, see:
    https://www.kdevelop.org/news/kdevelop-510-released
- Add okteta-devel BuildRequires to re-enable the okteta plugin
* Sun Mar  5 2017 wbauer@tmo.at
- New upstream release 5.0.4
  * QObject template: fix typo screwing redefinition of block
    extra_definitions
  * Update version number to 5.0.4
  * Clang: Fix missing DUChain lock
  * Custom-buildsystem: Fix crash while configuring (kde#335470)
  * Try to fix testGccCompatibility test for me
  * Clang: Also rename destructors when renaming class (kde#373452)
  * Fix bug with wrong CMake arguments during adding new build
    directory
  * Clang: Don't propose to refactor function defs
  * Fix comments in file template for Python unit test for
    setUp/tearDown (kde#321005)
  * Fix TestCustomBuildSystemPlugin by readding .kdev4 folders of
    test data
  * Providers: Fix some Qt runtime warnings
  * Update TestProblems::testMissingInclude() to current
    ClangFixitAssistant
  * QtHelp CSS images fix
  * QtHelp page loading fix
  * Update INSTALL
  * Streamline README
  * File_templates: Remove '#include "foo.moc"' footer
  * Prefer qmake over qmake-qt5 over qmake-qt4
  * Appimage: do not fail on git stash pop
  * Fix default icon for some plugin
  * I18n fixes
* Fri Dec  2 2016 wbauer@tmo.at
- New upstream release 5.0.3
  * Make the "Forward declare" problem solution assistant only pop
    up when it makes sense
  * Fix GitHub handling authentication (kde#372144)
  * Fix Qt help jumping to the wrong function sometimes
* Wed Nov 16 2016 wbauer@tmo.at
- New upstream release 5.0.2
  * Fix a possible crash when activating a clang FixIt (kde#369176)
  * Fix a crash when performing various actions with the Make
    plugin disabled (kde#369326)
  * Fix "Install as root" action not working
  * Fix CMake build plugin sometimes rebuilding everything when it
    should not
* Tue Oct  4 2016 lbeltrame@kde.org
- Add missing find_lang macros for additional translations
* Tue Oct  4 2016 lbeltrame@kde.org
- Add KArchive to BuildRequires and bump Frameworks versions
  (they were lower than in kdevplatform, and that did not make
  any sense)
* Mon Oct  3 2016 lbeltrame@kde.org
- New upstream release 5.0.1
  * Do not display the "project is already open in a different
    session" dialog on starting up a session under some
    circumstances.
  * Mouseover highlight now uses the "Search highlight" color from
    the configuration dialog, instead of a hard-coded bright
    yellow.
  * Fix working directory of Custom Makefile plugin
  * Fix a possible crash on triggering an assistant popup action
  * Fix a freeze under some circumstances when the welcome page is
    displayed.
* Thu Sep 22 2016 lbeltrame@kde.org
- Drop %%lang_package and use an explicit Conflicts on
  kdevelop4-lang to workaround issues in the Factory submission
  bot
* Wed Aug 24 2016 cgiboudeaux@gmx.com
- Update to 5.0.0
* Thu Jul 21 2016 wbauer@tmo.at
- Remove libQt5Declarative/QtQuick1 build requirement to fix build
  with Qt 5.7, it's not needed/used anyway
* Thu Jan 28 2016 tittiatcoke@gmail.com
- Initial package for kdevelop 5 based on Frameworks
  * Kdevelop 5 Beta 3
